@@ -20,6 +20,7 @@
 
 #include "platform.h"
 #include "extractor.h"
+#include <pthread.h>
 
 #if HAVE_LTDL_H
 #include <ltdl.h>
@@ -176,11 +177,13 @@ static const char *keywordTypes[] = {
   gettext_noop("track number"),
   gettext_noop("international standard recording code"),
   gettext_noop("disc number"), /* 134 */
+  gettext_noop("preferred display style (GNUnet)"),
+  gettext_noop("GNUnet URI of ECBC data"),
   NULL,
 };
 
 /* the number of keyword types (for bounds-checking) */
-#define HIGHEST_TYPE_NUMBER 135
+#define HIGHEST_TYPE_NUMBER 137
 
 #ifdef HAVE_LIBOGG
 #if HAVE_VORBIS
@@ -260,7 +263,10 @@ libextractor_oo:\
 libextractor_asf:\
 libextractor_sid:\
 libextractor_nsfe:\
-libextractor_nsf"
+libextractor_nsf:\
+libextractor_it:\
+libextractor_xm:\
+libextractor_s3m"
 
 #define DEFAULT_LIBRARIES MPEGSO EXSO OLESO OGGSO FLACSO QTSO DEFSO
 
@@ -725,6 +731,15 @@ EXTRACTOR_getKeywordTypeAsString(const EXTRACTOR_KeywordType type)
     return NULL;
 }
 
+static pthread_mutex_t ltdl_lock = PTHREAD_MUTEX_INITIALIZER;
+
+#define LTDL_MUTEX_LOCK                     \
+  if (pthread_mutex_lock (&ltdl_lock) != 0) \
+    abort();
+#define LTDL_MUTEX_UNLOCK                     \
+  if (pthread_mutex_unlock (&ltdl_lock) != 0) \
+    abort();
+
 static void *getSymbolWithPrefix(void *lib_handle,
                                  const char *lib_name,
                                  const char *sym_name)
@@ -743,6 +758,7 @@ static void *getSymbolWithPrefix(void *lib_handle,
 	   lib_name,
 	   sym_name);
 
+  LTDL_MUTEX_LOCK
   symbol=lt_dlsym(lib_handle,name+1 /* skip the '_' */);
   if (symbol==NULL) {
     first_error=strdup(lt_dlerror());
@@ -760,6 +776,7 @@ static void *getSymbolWithPrefix(void *lib_handle,
 #endif
     free(first_error);
   }
+  LTDL_MUTEX_UNLOCK
   free(name);
   return symbol;
 }
@@ -773,7 +790,20 @@ loadLibrary (const char *name,
 	     void **libHandle,
 	     ExtractMethod * method)
 {
+#if 0
+  lt_dladvise advise;
+#endif
+
+  LTDL_MUTEX_LOCK
+#if 0
+  lt_dladvise_init(&advise);
+  lt_dladvise_ext(&advise);
+  lt_dladvise_local(&advise);
+  *libHandle = lt_dlopenadvise (name, &advise);
+  lt_dladvise_destroy(&advise);
+#else
   *libHandle = lt_dlopenext (name);
+#endif
   if (*libHandle == NULL)
     {
 #if DEBUG
@@ -782,12 +812,16 @@ loadLibrary (const char *name,
 	       name,
 	       lt_dlerror ());
 #endif
+      LTDL_MUTEX_UNLOCK
       return -1;
     }
+  LTDL_MUTEX_UNLOCK
 
   *method = (ExtractMethod) getSymbolWithPrefix (*libHandle, name, "_extract");
   if (*method == NULL) {
+    LTDL_MUTEX_LOCK
     lt_dlclose (*libHandle);
+    LTDL_MUTEX_UNLOCK
     return -1;
   }
   return 1;
@@ -976,8 +1010,11 @@ EXTRACTOR_removeLibrary(EXTRACTOR_ExtractorList * prev,
       free (pos->libname);
       if( pos->options )
 	free (pos->options);
-      if( pos->libraryHandle )
+      if( pos->libraryHandle ) {
+        LTDL_MUTEX_LOCK
 	lt_dlclose (pos->libraryHandle);
+        LTDL_MUTEX_UNLOCK
+      }
       free (pos);
     }
 #if DEBUG
@@ -1703,6 +1740,8 @@ int EXTRACTOR_binaryDecode(const char * in,
   }
 
   buf = malloc(inSize); /* slightly more than needed ;-) */
+  if (buf == NULL)
+    return 1; /* error */
   *out = buf;
 
   pos = 0;
