@@ -2,14 +2,16 @@
 //
 // Parser.h
 //
-// Copyright 1996 Derek B. Noonburg
+// Copyright 1996-2003 Glyph & Cog, LLC
 //
 //========================================================================
 
 #ifndef PARSER_H
 #define PARSER_H
 
-#ifdef __GNUC__
+#include <aconf.h>
+
+#ifdef USE_GCC_PRAGMAS
 #pragma interface
 #endif
 
@@ -23,7 +25,7 @@ class Parser {
 public:
 
   // Constructor.
-  Parser(Lexer *lexerA);
+  Parser(XRef *xrefA, Lexer *lexerA);
 
   // Destructor.
   ~Parser();
@@ -45,6 +47,7 @@ public:
 
 private:
 
+  XRef *xref;			// the xref table for this PDF file
   Lexer *lexer;			// input stream
   Object buf1, buf2;		// next two tokens
   int inlineImg;		// set when inline image data is encountered
