@@ -33,7 +33,7 @@
 #include <Qt/qapplication.h>
 
 #ifdef HAVE_QT_SVG
-  #include <qsvgrenderer.h>
+  #include <Qt/qsvgrenderer.h>
   #include <Qt/qpainter.h>
 #endif
 
@@ -42,24 +42,6 @@
 extern "C"
 {
 
-QApplication *app;
-char *argv;
-
-void __attribute__ ((constructor)) thumnailextractorqt_init(void)
-{
-  int argc = 0;
-
-  argv = strdup("");
-  app = qApp ? NULL : new QApplication(argc, &argv);
-}
-
-void __attribute__ ((destructor)) thumnailextractorqt_done(void)
-{
-  if (qApp == app)
-    delete app;
-  free(argv);
-}
-
 static EXTRACTOR_KeywordList * addKeyword(EXTRACTOR_KeywordType type,
 					  char * keyword,
 					  EXTRACTOR_KeywordList * next) {
@@ -98,12 +80,11 @@ static char * whitelist[] = {
   NULL
 };
 
-struct EXTRACTOR_Keywords * 
-libextractor_thumbnailqt_extract(const char * filename,
-				 const unsigned char * data,
-				 size_t size,
-				 struct EXTRACTOR_Keywords * prev,
-				 const char * options) {
+static struct EXTRACTOR_Keywords * 
+extract(const unsigned char * data,
+	size_t size,
+	struct EXTRACTOR_Keywords * prev,
+	const char * options) {
   QImage *img;
   QByteArray bytes;
   QBuffer buffer;
@@ -237,6 +218,42 @@ libextractor_thumbnailqt_extract(const char * filename,
 		    prev);
 }
 
+/* create new thread for C++ code (see Mantis #905) */
+
+struct X {
+  const unsigned char * data;
+  size_t size;
+  struct EXTRACTOR_Keywords * prev;
+  const char * options;
+};
+
+static void * run(void * arg) {
+  struct X * x = (struct X*) arg;
+  return extract(x->data, x->size, x->prev,
+		 x->options);
+}
+
+struct EXTRACTOR_Keywords * 
+libextractor_thumbnailqt_extract(const char * filename,
+				 const unsigned char * data,
+				 size_t size,
+				 struct EXTRACTOR_Keywords * prev,
+				 const char * options) {
+  pthread_t pt;
+  struct X cls;
+
+  void * ret;
+  cls.data = data;
+  cls.size = size;
+  cls.prev = prev;
+  cls.options = options;
+  if (0 == pthread_create(&pt, NULL, &run, &cls))
+    if (0 == pthread_join(pt, &ret))
+      return (struct EXTRACTOR_Keywords*) ret;
+  return prev; 
+}
+
+
 struct EXTRACTOR_Keywords * 
 libextractor_thumbnail_extract(const char * filename,
 			       const unsigned char * data,
